@@ -1,6 +1,9 @@
 #ifndef _PROCMAN_MEMMAPS_H_
 #define _PROCMAN_MEMMAPS_H_
 
+#include <glib/gtypes.h>
+#include "procman.h"
+
 void 		create_memmaps_dialog (ProcData *procdata) G_GNUC_INTERNAL;
 
 #endif /* _PROCMAN_MEMMAPS_H_ */
